@@ -314,9 +314,9 @@ menubar_prop_init(
                 cgen->itemlabel_field, cgen->itemlist_cb);
         n = 0;
         item[n] = cgen->itemlabel_opmenu_items.String_item;
-        item_ptr[n] = AB_LABEL_STRING; n++;
+        item_ptr[n] = (void *) AB_LABEL_STRING; n++;
         item[n] = cgen->itemlabel_opmenu_items.Graphic_item;
-        item_ptr[n] = AB_LABEL_GLYPH; n++;
+        item_ptr[n] = (void *) AB_LABEL_GLYPH; n++;
         prop_options_init(&(pms->item_label_type), cgen->item_labeltype_label,
                 cgen->itemlabel_opmenu, cgen->itemlabel_opmenu_menu,
                 n, item, item_ptr, cgen->itemlist_cb);
